@@ -258,12 +258,13 @@ class RequestHandler(tornado.web.RequestHandler):
         # self.acct_db = self.application.settings.get('acct_db', NotImplemented)
 
         self.cache_db = self.application.settings.get('cache_db', NotImplemented)
+        self.session = self.application.settings.get('session', NotImplemented)
 
         #
         # self.files_db = self.application.settings.get('files_db', NotImplemented)
         # self.dbs = self.application.settings.get('dbs', NotImplemented)
 
-        # self.session = self.application.settings.get('session', NotImplemented)
+
         # self.statsd = self.application.settings.get('statsd', NotImplemented)
 
         # mail client
@@ -278,9 +279,10 @@ class RequestHandler(tornado.web.RequestHandler):
         self.db = None
         self.acct_db = None
         # self.cache_db=None
+        # self.session=None
         self.files_db=None
         self.dbs=None
-        self.session=None
+
         self.statsd=None
 
 
